### kohokoho (को हो को हो !)

#### Installation

`pip install kohokoho`

[![asciicast](https://asciinema.org/a/EQtBLYwDtucQ1qB1GK09adkjk.svg)](https://asciinema.org/a/EQtBLYwDtucQ1qB1GK09adkjk)


### Installation (from source)

#### Clone the repository

`git clone https://github.com/ayushsubedi/kohokoho`

#### CD into the cloned directory and create a virtualenv

`python -m venv env`

### Enable virtualenv

`.\env\Scripts\activate`

### Install dependency packages from requirements.txt

`pip install -r requirements.txt`

### Run the app

`python kohokoho.py --csv={location of csv file}`


